@@ -448,6 +448,16 @@ isc_arg_win32 = 17
 isc_arg_warning = 18
 isc_arg_sql_state = 19
 
+# Protocol Types (accept_type)
+ptype_batch_send = 3    # Batch sends, no asynchrony
+ptype_out_of_band = 4   # Batch sends w/ out of band notification
+ptype_lazy_send = 5     # Deferred packets delivery
+
+PROTOCOL_VERSION10 = 10
+PROTOCOL_VERSION11 = 11
+PROTOCOL_VERSION12 = 12
+PROTOCOL_VERSION13 = 13
+
 CNCT_user = 1
 CNCT_passwd = 2
 CNCT_host = 4
@@ -459,6 +469,9 @@ CNCT_login = 9
 CNCT_plugin_list = 10
 CNCT_client_crypt = 11
 
+DSQL_close = 1
+DSQL_drop = 2
+
 charset_map = {
     # DB CHAR SET NAME    :   PYTHON CODEC NAME (CANONICAL)
     # --------------------------------------------------------------------------
