@@ -26,7 +26,7 @@ except ImportError:
     from UserDict import DictMixin as Mapping
     HAS_MAPPING = False
 
-__version__ = '0.8.6'
+__version__ = '0.9.0'
 apilevel = '2.0'
 threadsafety = 1
 paramstyle = 'qmark'
@@ -76,57 +76,146 @@ NUMBER = DBAPITypeObject(int, decimal.Decimal)
 DATETIME = DBAPITypeObject(datetime.datetime, datetime.date, datetime.time)
 ROWID = DBAPITypeObject()
 
+class Statement(object):
+    """
+    statement handle and status (open/close)
+    """
+    def __init__(self, trans):
+        self.trans = trans
+        self._allocate_stmt()
+        self._is_open = False
+        self.trans.stmts.add(self)
 
-class PreparedStatement:
+    def _allocate_stmt(self):
+        self.trans.connection._op_allocate_statement()
+        if self.trans.connection.accept_type == ptype_lazy_send:
+            self.handle = -1
+        else:
+            (h, oid, buf) = self.trans.connection._op_response()
+            self.handle = h
+
+    def prepare(self, sql, explain_plan=False):
+        if self.handle == 0:
+            self._allocate_stmt()
+
+        if explain_plan:
+            self.trans.connection._op_prepare_statement(
+                self.handle, self.trans.trans_handle, sql,
+                option_items=bytes([isc_info_sql_get_plan]))
+        else:
+            self.trans.connection._op_prepare_statement(
+                self.handle, self.trans.trans_handle, sql)
+            self.plan = None
+
+        (h, oid, buf) = self.trans.connection._op_response()
+        if self.trans.connection.accept_type == ptype_lazy_send:
+            self.handle = h
+
+        i = 0
+        if byte_to_int(buf[i]) == isc_info_sql_get_plan:
+            l = bytes_to_int(buf[i+1:i+3])
+            self.plan = self.trans.connection.bytes_to_str(buf[i+3:i+3+l])
+            i += 3 + l
+
+        self.stmt_type, self.xsqlda = parse_xsqlda(buf[i:],
+                                    self.trans.connection, self.handle)
+
+    def open(self):
+        self._is_open = True
+
+    def _close(self):
+        self._is_open = False
+
+    def close(self):
+        if not self._is_open or self.handle == 0 or self.handle == -1:
+            return
+        self.trans.connection._op_free_statement(self.handle, DSQL_close)
+        if self.trans.connection.accept_type != ptype_lazy_send:
+            (h, oid, buf) = self.trans.connection._op_response()
+        self._close()
+
+    def drop(self):
+        if self.handle == 0 or self.handle == -1:
+            return
+        self.trans.connection._op_free_statement(self.handle, DSQL_drop)
+        if self.trans.connection.accept_type != ptype_lazy_send:
+            (h, oid, buf) = self.trans.connection._op_response()
+        self.handle = -1
+
+    def clear_handle(self):
+        self._is_open = False
+        self.handle = 0
+
+    @property
+    def is_opened(self):
+        return self._is_open and self.handle != 0
+
+class PreparedStatement(object):
     def __init__(self, cur, sql, explain_plan=False):
         self.cur = cur
         self.sql = sql
         transaction = self.cur.transaction
         connection = transaction.connection
 
-        connection._op_allocate_statement()
-        (h, oid, buf) = connection._op_response()
-        self.stmt_handle = h
-        self.is_opened = False
-
-        if explain_plan:
-            connection._op_prepare_statement(
-                self.stmt_handle, transaction.trans_handle, sql,
-                option_items=bytes([isc_info_sql_get_plan]))
-        else:
-            connection._op_prepare_statement(
-                self.stmt_handle, transaction.trans_handle, sql)
-            self.plan = None
-
-        (h, oid, buf) = connection._op_response()
-
-        i = 0
-        if byte_to_int(buf[i]) == isc_info_sql_get_plan:
-            l = bytes_to_int(buf[i+1:i+3])
-            self.plan = connection.bytes_to_str(buf[i+3:i+3+l])
-            i += 3 + l
-
-        self.statement_type, self._xsqlda = parse_xsqlda(
-                                        buf[i:], connection, self.stmt_handle)
+        self.stmt = Statement(transaction)
+        self.stmt.prepare(sql, explain_plan)
 
     def __getattr__(self, attrname):
         if attrname == 'description':
-            if len(self._xsqlda) == 0:
+            if len(self.stmt.xsqlda) == 0:
                 return None
             r = []
-            for x in self._xsqlda:
+            for x in self.stmt.xsqlda:
                 r.append((x.aliasname, x.sqltype, x.display_length(),
                         x.io_length(), x.precision(),
                         x.sqlscale, True if x.null_ok else False))
             return r
         elif attrname == 'n_output_params':
-            return len(self._xsqlda)
+            return len(self.stmt.xsqlda)
         raise AttributeError
 
-class Cursor:
+
+def _fetch_generator(stmt):
+    stmt.open()
+    connection = stmt.trans.connection
+    more_data = True
+    while more_data:
+        if not stmt.is_opened:
+            raise StopIteration()
+        connection._op_fetch(stmt.handle, calc_blr(stmt.xsqlda))
+        (rows, more_data) = connection._op_fetch_response(
+                                        stmt.handle, stmt.xsqlda)
+        for r in rows:
+            # Convert BLOB handle to data
+            for i in range(len(stmt.xsqlda)):
+                x = stmt.xsqlda[i]
+                if x.sqltype == SQL_TYPE_BLOB:
+                    if not r[i]:
+                        continue
+                    connection._op_open_blob(r[i], stmt.trans.trans_handle)
+                    (h, oid, buf) = connection._op_response()
+                    v = bytes([])
+                    n = 1   # 1:mora data 2:no more data
+                    while n == 1:
+                        connection._op_get_segment(h)
+                        (n, oid, buf) = connection._op_response()
+                        while buf:
+                            ln = bytes_to_int(buf[:2])
+                            v += buf[2:ln+2]
+                            buf = buf[ln+2:]
+                    connection._op_close_blob(h)
+                    if connection.accept_type != ptype_lazy_send:
+                        (h, oid, buf) = connection._op_response()
+                    r[i] = v
+                    if x.sqlsubtype == 1:    # TEXT
+                        r[i] = connection.bytes_to_str(r[i])
+            yield r
+    raise StopIteration()
+
+class Cursor(object):
     def __init__(self, trans):
         self._transaction = trans
-        self.stmt_handle = None
+        self.stmt = None
         self.arraysize = 1
 
     def __enter__(self):
@@ -148,30 +237,19 @@ class Cursor:
             cooked_params.append(param)
         return cooked_params
 
-    def _get_stmt_handle(self, query):
+    def _get_stmt(self, query):
+        self.query = query
         if isinstance(query, PreparedStatement):
-            if query.is_opened:
-                self.transaction.connection._op_free_statement(
-                                            query.stmt_handle, 1) # DSQL_close
-                (h, oid, buf) = self.transaction.connection._op_response()
-            stmt_handle = query.stmt_handle
-            stmt_type = query.statement_type
-            self._xsqlda = query._xsqlda
-            query.is_opened = True
+            stmt = query.stmt
+            stmt.close()
         else:
-            if self.stmt_handle:
-                self.transaction.connection._op_free_statement(
-                                            self.stmt_handle, 2) # DSQL_drop
-                (h, oid, buf) = self.transaction.connection._op_response()
-            self.transaction.connection._op_allocate_statement()
-            (stmt_handle, oid, buf) = self.transaction.connection._op_response()
-            self.stmt_handle = stmt_handle
-            self.transaction.connection._op_prepare_statement(stmt_handle,
-                                        self.transaction.trans_handle, query)
-            (h, oid, buf) = self.transaction.connection._op_response()
-            stmt_type, self._xsqlda = parse_xsqlda(
-                                buf, self.transaction.connection, stmt_handle)
-        return stmt_type, stmt_handle
+            if self.stmt:
+                self.stmt.close()
+            else:
+                self.stmt = Statement(self.transaction)
+            stmt = self.stmt
+            stmt.prepare(query)
+        return stmt
 
     def _execute(self, stmt_handle, params):
         cooked_params = self._convert_params(params)
@@ -191,20 +269,20 @@ class Cursor:
         return prepared_statement
 
     def execute(self, query, params=[]):
-        stmt_type, stmt_handle = self._get_stmt_handle(query)
-        if stmt_type == isc_info_sql_stmt_exec_procedure:
+        stmt = self._get_stmt(query)
+        if stmt.stmt_type == isc_info_sql_stmt_exec_procedure:
             cooked_params = self._convert_params(params)
-            self.transaction.connection._op_execute2(stmt_handle,
+            self.transaction.connection._op_execute2(stmt.handle,
                 self.transaction.trans_handle, cooked_params,
-                calc_blr(self._xsqlda))
+                calc_blr(stmt.xsqlda))
             self._callproc_result = \
-                self.transaction.connection._op_sql_response(self._xsqlda)
+                self.transaction.connection._op_sql_response(stmt.xsqlda)
             self.transaction.connection._op_response()
             self._fetch_records = None
         else:
-            self._execute(stmt_handle, params)
-            if stmt_type == isc_info_sql_stmt_select:
-                self._fetch_records = self._fetch_generator(stmt_handle)
+            self._execute(stmt.handle, params)
+            if stmt.stmt_type == isc_info_sql_stmt_select:
+                self._fetch_records = _fetch_generator(stmt)
             else:
                 self._fetch_records = None
             self._callproc_result = None
@@ -217,39 +295,6 @@ class Cursor:
         for params in seq_of_params:
             self.execute(query, params)
 
-    def _fetch_generator(self, stmt_handle):
-        connection = self.transaction.connection
-        more_data = True
-        while more_data:
-            connection._op_fetch(stmt_handle, calc_blr(self._xsqlda))
-            (rows, more_data) = connection._op_fetch_response(
-                                            stmt_handle, self._xsqlda)
-            for r in rows:
-                # Convert BLOB handle to data
-                for i in range(len(self._xsqlda)):
-                    x = self._xsqlda[i]
-                    if x.sqltype == SQL_TYPE_BLOB:
-                        if not r[i]:
-                            continue
-                        connection._op_open_blob(r[i], self.transaction.trans_handle)
-                        (h, oid, buf) = connection._op_response()
-                        v = bytes([])
-                        n = 1   # 1:mora data 2:no more data
-                        while n == 1:
-                            connection._op_get_segment(h)
-                            (n, oid, buf) = connection._op_response()
-                            while buf:
-                                ln = bytes_to_int(buf[:2])
-                                v += buf[2:ln+2]
-                                buf = buf[ln+2:]
-                        connection._op_close_blob(h)
-                        (h, oid, buf) = connection._op_response()
-                        r[i] = v
-                        if x.sqlsubtype == 1:    # TEXT
-                            r[i] = connection.bytes_to_str(r[i])
-                yield r
-
-        raise StopIteration()
 
     def fetchone(self):
         # callproc or not select statement
@@ -326,11 +371,10 @@ class Cursor:
             r = self.fetchonemap()
 
     def close(self):
-        if not self.stmt_handle:
+        if not self.stmt:
             return
-        self.transaction.connection._op_free_statement(self.stmt_handle, 2)   # DSQL_drop
-        (h, oid, buf) = self.transaction.connection._op_response()
-        self.stmt_handle = None
+        self.stmt.drop()
+        self.stmt = None
 
     def nextset(self):
         raise NotSupportedError()
@@ -343,36 +387,34 @@ class Cursor:
 
     @property
     def description(self):
-        if not hasattr(self, "_xsqlda"):
+        if not self.stmt:
             return None
         return [(x.aliasname, x.sqltype, x.display_length(), x.io_length(),
                     x.precision(), x.sqlscale, True if x.null_ok else False)
-                for x in self._xsqlda]
+                for x in self.stmt.xsqlda]
 
     @property
     def rowcount(self):
-        self.transaction.connection._op_info_sql(self.stmt_handle,
-                                     bytes([isc_info_sql_stmt_type]))
-        (h, oid, buf) = self.transaction.connection._op_response()
-        assert buf[:3] == bytes([0x15,0x04,0x00]) # isc_info_sql_stmt_type
-        stmt_type = bytes_to_int(buf[3:7])
+        if not self.stmt.is_opened:
+            return -1
 
-        self.transaction.connection._op_info_sql(self.stmt_handle,
+        self.transaction.connection._op_info_sql(self.stmt.handle,
                                      bytes([isc_info_sql_records]))
         (h, oid, buf) = self.transaction.connection._op_response()
         assert buf[:3] == bytes([0x17,0x1d,0x00]) # isc_info_sql_records
-        if stmt_type == isc_info_sql_stmt_select:
-            # rowcount for select stmt changes based on num rows fetched
-            count = -1
-        elif stmt_type == isc_info_sql_stmt_insert:
+        if self.stmt.stmt_type == isc_info_sql_stmt_select:
+            assert buf[17:20] == bytes([0x0d,0x04,0x00])
+                                              # isc_info_req_select_count
+            count = bytes_to_int(buf[20:24])
+        elif self.stmt.stmt_type == isc_info_sql_stmt_insert:
             assert buf[24:27] == bytes([0x0e,0x04,0x00])
                                               # isc_info_req_insert_count
             count = bytes_to_int(buf[27:31])
-        elif stmt_type == isc_info_sql_stmt_update:
+        elif self.stmt.stmt_type == isc_info_sql_stmt_update:
             assert buf[3:6] == bytes([0x0f,0x04,0x00])
                                               # isc_info_req_update_count
             count = bytes_to_int(buf[6:10])
-        elif stmt_type == isc_info_sql_stmt_delete:
+        elif self.stmt.stmt_type == isc_info_sql_stmt_delete:
             assert buf[10:13] == bytes([0x10,0x04,0x00])
                                               # isc_info_req_delete_count
             count = bytes_to_int(buf[13:17])
@@ -452,13 +494,14 @@ class Connection(WireProtocol):
         self._op_exec_immediate(
             self._transaction.trans_handle, query=query)
         (h, oid, buf) = self._op_response()
+        self.is_dirty = True
 
     def __init__(self, dsn=None, user=None, password=None, role=None, host=None,
                     database=None, charset=DEFAULT_CHARSET, port=3050,
                     page_size=4096, is_services=False, cloexec=False,
                     timeout=None, isolation_level=None, use_unicode=None,
-                    connect_version=2, use_srp=True, wire_crypt=True,
-                    create_new=False):
+                    auth_plugin_list=('Srp', 'Legacy_Auth'),
+                    wire_crypt=True, create_new=False):
         self.db_handle = None
         if dsn:
             i = dsn.find(':')
@@ -485,6 +528,8 @@ class Connection(WireProtocol):
         self.role = role
         self.charset = charset
         self.timeout = float(timeout) if timeout is not None else None
+        self.auth_plugin_list = auth_plugin_list
+        self.wire_crypt = wire_crypt
         self.page_size = page_size
         self.is_services = is_services
         if isolation_level is None:
@@ -492,13 +537,12 @@ class Connection(WireProtocol):
         else:
             self.isolation_level = int(isolation_level)
         self.use_unicode = use_unicode
-        self.connect_version = connect_version
         self.last_event_id = 0
 
         self._transaction = None
         self.sock = SocketStream(self.hostname, self.port, self.timeout, cloexec)
 
-        self._op_connect(use_srp, wire_crypt)
+        self._op_connect(auth_plugin_list, wire_crypt)
         try:
             self._op_accept()
         except OperationalError:
@@ -663,8 +707,6 @@ class Connection(WireProtocol):
     def close(self):
         if self.sock is None:
             return
-        if self._transaction:
-            self._transaction.close()
         if self.db_handle:
             if self.is_services:
                 self._op_service_detach()
@@ -692,27 +734,32 @@ class Connection(WireProtocol):
     def is_disconnect(self):
         return self.sock is None
 
-class Transaction:
+class Transaction(object):
     def __init__(self, connection, tpb=None):
         self._connection = connection
         self._trans_handle = None
+        self.stmts = set()
 
     def _begin(self):
-        self._close()
         self.connection._op_transaction(
                 transaction_parameter_block[self.connection.isolation_level])
         (h, oid, buf) = self.connection._op_response()
         self._trans_handle = h
 
-    def _close(self):
-        if self._trans_handle:
-            self.connection._op_rollback(self.trans_handle)
-            (h, oid, buf) = self.connection._op_response()
-        self._trans_handle = None
-
     def begin(self):
         self._begin()
 
+    def savepoint(self, name):
+        if self._trans_handle is None:
+            return
+        self.connection._op_exec_immediate(self._trans_handle,
+                        query='SAVEPOINT '+name)
+        (h, oid, buf) = self.connection._op_response()
+
+    def _clear_stmts(self):
+        for s in self.stmts:
+            s.clear_handle()
+
     def commit(self, retaining=False):
         if self._trans_handle is None:
             return
@@ -720,17 +767,11 @@ class Transaction:
             self.connection._op_commit_retaining(self._trans_handle)
             (h, oid, buf) = self.connection._op_response()
         else:
+            self._clear_stmts()
             self.connection._op_commit(self._trans_handle)
             (h, oid, buf) = self.connection._op_response()
             self._trans_handle = None
 
-    def savepoint(self, name):
-        if self._trans_handle is None:
-            return
-        self.connection._op_exec_immediate(self._trans_handle,
-                        query='SAVEPOINT '+name)
-        (h, oid, buf) = self.connection._op_response()
-
     def rollback(self, retaining=False, savepoint=None):
         if self._trans_handle is None:
             return
@@ -739,11 +780,11 @@ class Transaction:
                         query='ROLLBACK TO '+savepoint)
             (h, oid, buf) = self.connection._op_response()
             return
-
         if retaining:
             self.connection._op_rollback_retaining(self._trans_handle)
             (h, oid, buf) = self.connection._op_response()
         else:
+            self._clear_stmts()
             self.connection._op_rollback(self._trans_handle)
             (h, oid, buf) = self.connection._op_response()
             self._trans_handle = None
@@ -788,9 +829,6 @@ class Transaction:
                 results[info_requests[i]] = v
             return results
 
-    def close(self):
-        self._close()
-
     @property
     def connection(self):
         return self._connection
