@@ -118,7 +118,7 @@ messages = {
     335544426 : '''context not defined (BLR error)\n''', 
     335544427 : '''data operation not supported\n''', 
     335544428 : '''undefined message number\n''', 
-    335544429 : '''bad parameter number\n''', 
+    335544429 : '''undefined parameter number\n''', 
     335544430 : '''unable to allocate memory from operating system\n''', 
     335544431 : '''blocking signal has been received\n''', 
     335544432 : '''lock manager error\n''', 
@@ -240,10 +240,10 @@ messages = {
     335544548 : '''Attempt to define a second PRIMARY KEY for the same table\n''', 
     335544549 : '''cannot modify or erase a system trigger\n''', 
     335544550 : '''only the owner of a table may reassign ownership\n''', 
-    335544551 : '''could not find table/procedure for GRANT\n''', 
+    335544551 : '''could not find object for GRANT\n''', 
     335544552 : '''could not find column for GRANT\n''', 
     335544553 : '''user does not have GRANT privileges for operation\n''', 
-    335544554 : '''table/procedure has non-SQL security class defined\n''', 
+    335544554 : '''object has non-SQL security class defined\n''', 
     335544555 : '''column has non-SQL security class defined\n''', 
     335544556 : '''Write-ahead Log without shared cache configuration not allowed\n''', 
     335544557 : '''database shutdown unsuccessful\n''', 
@@ -333,7 +333,7 @@ messages = {
     335544641 : '''Specified domain or source column @1 does not exist\n''', 
     335544642 : '''index @1 cannot be used in the specified plan\n''', 
     335544643 : '''the table @1 is referenced twice; use aliases to differentiate\n''', 
-    335544644 : '''illegal operation when at beginning of stream\n''', 
+    335544644 : '''attempt to fetch before the first record in a record stream\n''', 
     335544645 : '''the current position is on a crack\n''', 
     335544646 : '''database or file exists\n''', 
     335544647 : '''invalid comparison operator for find operation\n''', 
@@ -489,7 +489,7 @@ messages = {
     335544797 : '''user name and password are required while attaching to the services manager\n''', 
     335544798 : '''You created an indirect dependency on uncommitted metadata. You must roll back the current transaction.\n''', 
     335544799 : '''The service name was not specified.\n''', 
-    335544800 : '''Too many Contexts of Relation/Procedure/Views. Maximum allowed is 255\n''', 
+    335544800 : '''Too many Contexts of Relation/Procedure/Views. Maximum allowed is 256\n''', 
     335544801 : '''data type not supported for arithmetic\n''', 
     335544802 : '''Database dialect being changed from 3 to 1\n''', 
     335544803 : '''Database dialect not changed.\n''', 
@@ -511,11 +511,11 @@ messages = {
     335544819 : '''File exceeded maximum size of 2GB.  Add another database file or use a 64 bit I/O version of Firebird.\n''', 
     335544820 : '''Unable to find savepoint with name @1 in transaction context\n''', 
     335544821 : '''Invalid column position used in the @1 clause\n''', 
-    335544822 : '''Cannot use an aggregate function in a WHERE clause, use HAVING instead\n''', 
-    335544823 : '''Cannot use an aggregate function in a GROUP BY clause\n''', 
+    335544822 : '''Cannot use an aggregate or window function in a WHERE clause, use HAVING (for aggregate only) instead\n''', 
+    335544823 : '''Cannot use an aggregate or window function in a GROUP BY clause\n''', 
     335544824 : '''Invalid expression in the @1 (not contained in either an aggregate function or the GROUP BY clause)\n''', 
     335544825 : '''Invalid expression in the @1 (neither an aggregate function nor a part of the GROUP BY clause)\n''', 
-    335544826 : '''Nested aggregate functions are not allowed\n''', 
+    335544826 : '''Nested aggregate and window functions are not allowed\n''', 
     335544827 : '''Invalid argument in EXECUTE STATEMENT - cannot convert to string\n''', 
     335544828 : '''Wrong request type in EXECUTE STATEMENT '@1'\n''', 
     335544829 : '''Variable type (position @1) in EXECUTE STATEMENT '@2' INTO does not match returned column type\n''', 
@@ -525,7 +525,7 @@ messages = {
     335544833 : '''Physical backup is not allowed while Write-Ahead Log is in use\n''', 
     335544834 : '''Cursor is not open\n''', 
     335544835 : '''Target shutdown mode is invalid for database "@1"\n''', 
-    335544836 : '''Concatenation overflow. Resulting string cannot exceed 32K in length.\n''', 
+    335544836 : '''Concatenation overflow. Resulting string cannot exceed 32765 bytes in length.\n''', 
     335544837 : '''Invalid offset parameter @1 to SUBSTRING. Only positive integers are allowed.\n''', 
     335544838 : '''Foreign key reference target does not exist\n''', 
     335544839 : '''Foreign key references are present for the record\n''', 
@@ -677,7 +677,91 @@ messages = {
     335544985 : '''No free space found in temporary directories\n''', 
     335544986 : '''Explicit transaction control is not allowed\n''', 
     335544987 : '''Use of TRUSTED switches in spb_command_line is prohibited\n''', 
+    335544988 : '''PACKAGE @1\n''', 
+    335544989 : '''Cannot make field @1 of table @2 NOT NULL because there are NULLs present\n''', 
+    335544990 : '''Feature @1 is not supported anymore\n''', 
+    335544991 : '''VIEW @1\n''', 
+    335544992 : '''Can not access lock files directory @1\n''', 
+    335544993 : '''Fetch option @1 is invalid for a non-scrollable cursor\n''', 
+    335544994 : '''Error while parsing function @1's BLR\n''', 
+    335544995 : '''Cannot execute function @1 of the unimplemented package @2\n''', 
+    335544996 : '''Cannot execute procedure @1 of the unimplemented package @2\n''', 
+    335544997 : '''External function @1 not returned by the external engine plugin @2\n''', 
+    335544998 : '''External procedure @1 not returned by the external engine plugin @2\n''', 
+    335544999 : '''External trigger @1 not returned by the external engine plugin @2\n''', 
+    335545000 : '''Incompatible plugin version @1 for external engine @2\n''', 
+    335545001 : '''External engine @1 not found\n''', 
+    335545002 : '''Attachment is in use\n''', 
+    335545003 : '''Transaction is in use\n''', 
+    335545004 : '''Plugin @1 not found\n''', 
+    335545005 : '''Module @1 exists, but can not be loaded\n''', 
+    335545006 : '''Entrypoint of plugin @1 does not exist\n''', 
+    335545007 : '''Invalid value @1 for parameter index at PluginImpl::getConfigInfo: out of bounds\n''', 
+    335545008 : '''Plugin @1 does not create @2 instances\n''', 
+    335545009 : '''Invalid usage of context namespace DDL_TRIGGER\n''', 
+    335545010 : '''Value is NULL but isNull parameter was not informed\n''', 
+    335545011 : '''Type @1 is incompatible with BLOB\n''', 
+    335545012 : '''Invalid date\n''', 
+    335545013 : '''Invalid time\n''', 
+    335545014 : '''Invalid timestamp\n''', 
+    335545015 : '''Invalid index @1 in function @2\n''', 
+    335545016 : '''@1\n''', 
     335545017 : '''Asynchronous call is already running for this attachment\n''', 
+    335545018 : '''Function @1 is private to package @2\n''', 
+    335545019 : '''Procedure @1 is private to package @2\n''', 
+    335545020 : '''Request can't access new records in relation @1 and should be recompiled\n''', 
+    335545021 : '''invalid events id (handle)\n''', 
+    335545022 : '''Cannot copy statement @1\n''', 
+    335545023 : '''Invalid usage of boolean expression\n''', 
+    335545024 : '''Arguments for @1 cannot both be zero\n''', 
+    335545025 : '''missing service ID in spb\n''', 
+    335545026 : '''External BLR message mismatch: invalid null descriptor at field @1\n''', 
+    335545027 : '''External BLR message mismatch: length = @1, expected @2\n''', 
+    335545028 : '''Subscript @1 out of bounds [@2, @3]\n''', 
+    335545029 : '''Install incomplete, please read chapter "Initializing security database" in Quick Start Guide\n''', 
+    335545030 : '''@1 operation is not allowed for system table @2\n''', 
+    335545031 : '''Libtommath error code @1 in function @2\n''', 
+    335545032 : '''unsupported BLR version (expected between @1 and @2, encountered @3)\n''', 
+    335545033 : '''expected length @1, actual @2\n''', 
+    335545034 : '''Wrong info requested in isc_svc_query() for anonymous service\n''', 
+    335545035 : '''No isc_info_svc_stdin in user request, but service thread requested stdin data\n''', 
+    335545036 : '''Start request for anonymous service is impossible\n''', 
+    335545037 : '''All services except for getting server log require switches\n''', 
+    335545038 : '''Size of stdin data is more than was requested from client\n''', 
+    335545039 : '''Crypt plugin @1 failed to load\n''', 
+    335545040 : '''Length of crypt plugin name should not exceed @1 bytes\n''', 
+    335545041 : '''Crypt failed - already crypting database\n''', 
+    335545042 : '''Crypt failed - database is already in requested state\n''', 
+    335545043 : '''Missing crypt plugin, but page appears encrypted\n''', 
+    335545044 : '''No providers loaded\n''', 
+    335545045 : '''NULL data with non-zero SPB length\n''', 
+    335545046 : '''Maximum (@1) number of arguments exceeded for function @2\n''', 
+    335545047 : '''External BLR message mismatch: names count = @1, blr count = @2\n''', 
+    335545048 : '''External BLR message mismatch: name @1 not found\n''', 
+    335545049 : '''Invalid resultset interface\n''', 
+    335545050 : '''Message length passed from user application does not match set of columns\n''', 
+    335545051 : '''Resultset is missing output format information\n''', 
+    335545052 : '''Message metadata not ready - item @1 is not finished\n''', 
+    335545053 : '''Missing configuration file: @1\n''', 
+    335545054 : '''@1: illegal line <@2>\n''', 
+    335545055 : '''Invalid include operator in @1 for <@2>\n''', 
+    335545056 : '''Include depth too big\n''', 
+    335545057 : '''File to include not found\n''', 
+    335545058 : '''Only the owner can change the ownership\n''', 
+    335545059 : '''undefined variable number\n''', 
+    335545060 : '''Missing security context for database @1\n''', 
+    335545061 : '''Missing segment @1 in multisegment connect block parameter\n''', 
+    335545062 : '''Different logins in connect and attach packets - client library error\n''', 
+    335545063 : '''Exceeded exchange limit during authentication handshake\n''', 
+    335545064 : '''Incompatible wire encryption levels requested on client and server\n''', 
+    335545065 : '''Client attempted to attach unencrypted but wire encryption is required\n''', 
+    335545066 : '''Client attempted to start wire encryption using unknown key @1\n''', 
+    335545067 : '''Client attempted to start wire encryption using unsupported plugin @1\n''', 
+    335545068 : '''Error getting security database name from configuration file\n''', 
+    335545069 : '''Client authentication plugin is missing required data from server\n''', 
+    335545070 : '''Client authentication plugin expected @2 bytes of @3 from server, got @1\n''', 
+    335545071 : '''Attempt to get information about an unprepared dynamic SQL statement.\n''', 
+    335545072 : '''Problematic key value is @1\n''', 
     335740929 : '''data base file name (@1) already given\n''', 
     335740930 : '''invalid switch @1\n''', 
     335740932 : '''incompatible switch combination\n''', 
@@ -735,7 +819,22 @@ messages = {
     336003101 : '''UPDATE OR INSERT without MATCHING could not be used with views based on more than one table\n''', 
     336003102 : '''Incompatible trigger type\n''', 
     336003103 : '''Database trigger type can't be changed\n''', 
+    336003104 : '''To be used with RDB$RECORD_VERSION, @1 must be a table or a view of single table\n''', 
+    336068645 : '''BLOB Filter @1 not found\n''', 
+    336068649 : '''Function @1 not found\n''', 
+    336068656 : '''Index not found\n''', 
+    336068662 : '''View @1 not found\n''', 
+    336068697 : '''Domain not found\n''', 
+    336068717 : '''Triggers created automatically cannot be modified\n''', 
     336068740 : '''Table @1 already exists\n''', 
+    336068748 : '''Procedure @1 not found\n''', 
+    336068752 : '''Exception not found\n''', 
+    336068754 : '''Parameter @1 in procedure @2 not found\n''', 
+    336068755 : '''Trigger @1 not found\n''', 
+    336068759 : '''Character set @1 not found\n''', 
+    336068760 : '''Collation @1 not found\n''', 
+    336068763 : '''Role @1 not found\n''', 
+    336068767 : '''Name longer than database column size\n''', 
     336068784 : '''column @1 does not exist in table/view @2\n''', 
     336068796 : '''SQL role @1 does not exist\n''', 
     336068797 : '''user @1 has no grant admin option on SQL role @2\n''', 
@@ -754,9 +853,16 @@ messages = {
     336068817 : '''Cannot change datatype for @1.  Conversion from base type @2 to @3 is not supported.\n''', 
     336068818 : '''Cannot change datatype for column @1 from a character type to a non-character type.\n''', 
     336068820 : '''Zero length identifiers are not allowed\n''', 
+    336068822 : '''Sequence @1 not found\n''', 
     336068829 : '''Maximum number of collations per character set exceeded\n''', 
     336068830 : '''Invalid collation attributes\n''', 
     336068840 : '''@1 cannot reference @2\n''', 
+    336068843 : '''Collation @1 is used in table @2 (field name @3) and cannot be dropped\n''', 
+    336068844 : '''Collation @1 is used in domain @2 and cannot be dropped\n''', 
+    336068845 : '''Cannot delete system collation\n''', 
+    336068846 : '''Cannot delete default collation of CHARACTER SET @1\n''', 
+    336068849 : '''Table @1 not found\n''', 
+    336068851 : '''Collation @1 is used in procedure @2 (parameter name @3) and cannot be dropped\n''', 
     336068852 : '''New scale specified for column @1 must be at most @2.\n''', 
     336068853 : '''New precision specified for column @1 must be at least @2.\n''', 
     336068855 : '''Warning: @1 on @2 is not granted to @3.\n''', 
@@ -764,6 +870,27 @@ messages = {
     336068857 : '''Cannot add or remove COMPUTED from column @1\n''', 
     336068858 : '''Password should not be empty string\n''', 
     336068859 : '''Index @1 already exists\n''', 
+    336068864 : '''Package @1 not found\n''', 
+    336068865 : '''Schema @1 not found\n''', 
+    336068866 : '''Cannot ALTER or DROP system procedure @1\n''', 
+    336068867 : '''Cannot ALTER or DROP system trigger @1\n''', 
+    336068868 : '''Cannot ALTER or DROP system function @1\n''', 
+    336068869 : '''Invalid DDL statement for procedure @1\n''', 
+    336068870 : '''Invalid DDL statement for trigger @1\n''', 
+    336068871 : '''Function @1 has not been defined on the package body @2\n''', 
+    336068872 : '''Procedure @1 has not been defined on the package body @2\n''', 
+    336068873 : '''Function @1 has a signature mismatch on package body @2\n''', 
+    336068874 : '''Procedure @1 has a signature mismatch on package body @2\n''', 
+    336068875 : '''Default values for parameters are allowed only in declaration of packaged procedure @1.@2\n''', 
+    336068877 : '''Package body @1 already exists\n''', 
+    336068878 : '''Invalid DDL statement for function @1\n''', 
+    336068879 : '''Cannot alter new style function @1 with ALTER EXTERNAL FUNCTION. Use ALTER FUNCTION instead.\n''', 
+    336068886 : '''Parameter @1 in function @2 not found\n''', 
+    336068887 : '''Parameter @1 of routine @2 not found\n''', 
+    336068888 : '''Parameter @1 of routine @2 is ambiguous (found in both procedures and functions). Use a specifier keyword.\n''', 
+    336068889 : '''Collation @1 is used in function @2 (parameter name @3) and cannot be dropped\n''', 
+    336068890 : '''Domain @1 is used in function @2 (parameter name @3) and cannot be dropped\n''', 
+    336068891 : '''ALTER USER requires at least one clause to be specified\n''', 
     336330753 : '''found unknown switch\n''', 
     336330754 : '''page size parameter missing\n''', 
     336330755 : '''Page size specified (@1) greater than limit (16384 bytes)\n''', 
@@ -803,7 +930,7 @@ messages = {
     336330793 : '''expected data attribute\n''', 
     336330794 : '''Failed in store_blr_gen_id\n''', 
     336330795 : '''do not recognize record type @1\n''', 
-    336330796 : '''Expected backup version 1..9.  Found @1\n''', 
+    336330796 : '''Expected backup version 1..10.  Found @1\n''', 
     336330797 : '''expected backup description record\n''', 
     336330798 : '''string truncated\n''', 
     336330799 : '''warning -- record could not be restored\n''', 
@@ -837,7 +964,7 @@ messages = {
     336331015 : '''file @1 out of sequence\n''', 
     336331016 : '''can't join -- one of the files missing\n''', 
     336331017 : ''' standard input is not supported when using join operation\n''', 
-    336331018 : '''standard output is not supported when using split operation\n''', 
+    336331018 : '''standard output is not supported when using split operation or in verbose mode\n''', 
     336331019 : '''backup file @1 might be corrupt\n''', 
     336331020 : '''database file specification missing\n''', 
     336331021 : '''can't write a header record to file @1\n''', 
@@ -848,8 +975,20 @@ messages = {
     336331031 : '''"read_only" or "read_write" required\n''', 
     336331033 : '''just data ignore all constraints etc.\n''', 
     336331034 : '''restoring data only ignoring foreign key, unique, not null & other constraints\n''', 
+    336331078 : '''verbose interval value parameter missing\n''', 
+    336331079 : '''verbose interval value cannot be smaller than @1\n''', 
+    336331081 : '''verify (verbose) and verbint options are mutually exclusive\n''', 
+    336331082 : '''option -@1 is allowed only on restore or create\n''', 
+    336331083 : '''option -@1 is allowed only on backup\n''', 
+    336331084 : '''options -@1 and -@2 are mutually exclusive\n''', 
+    336331085 : '''parameter for option -@1 was already specified with value "@2"\n''', 
+    336331086 : '''option -@1 was already specified\n''', 
+    336331091 : '''dependency depth greater than @1 for view @2\n''', 
+    336331092 : '''value greater than @1 when calculating length of rdb$db_key for view @2\n''', 
     336331093 : '''Invalid metadata detected. Use -FIX_FSS_METADATA option.\n''', 
     336331094 : '''Invalid data detected. Use -FIX_FSS_DATA option.\n''', 
+    336331096 : '''Expected backup version @2..@3.  Found @1\n''', 
+    336331100 : '''database format @1 is too old to backup\n''', 
     336397205 : '''ODS versions before ODS@1 are not supported\n''', 
     336397206 : '''Table @1 does not exist\n''', 
     336397207 : '''View @1 does not exist\n''', 
@@ -903,6 +1042,70 @@ messages = {
     336397255 : '''Strings cannot be negated (applied the minus operator) in dialect 3\n''', 
     336397256 : '''Invalid data type for negation (minus operator)\n''', 
     336397257 : '''Cannot have more than 255 items in DISTINCT list\n''', 
+    336397258 : '''ALTER CHARACTER SET @1 failed\n''', 
+    336397259 : '''COMMENT ON @1 failed\n''', 
+    336397260 : '''CREATE FUNCTION @1 failed\n''', 
+    336397261 : '''ALTER FUNCTION @1 failed\n''', 
+    336397262 : '''CREATE OR ALTER FUNCTION @1 failed\n''', 
+    336397263 : '''DROP FUNCTION @1 failed\n''', 
+    336397264 : '''RECREATE FUNCTION @1 failed\n''', 
+    336397265 : '''CREATE PROCEDURE @1 failed\n''', 
+    336397266 : '''ALTER PROCEDURE @1 failed\n''', 
+    336397267 : '''CREATE OR ALTER PROCEDURE @1 failed\n''', 
+    336397268 : '''DROP PROCEDURE @1 failed\n''', 
+    336397269 : '''RECREATE PROCEDURE @1 failed\n''', 
+    336397270 : '''CREATE TRIGGER @1 failed\n''', 
+    336397271 : '''ALTER TRIGGER @1 failed\n''', 
+    336397272 : '''CREATE OR ALTER TRIGGER @1 failed\n''', 
+    336397273 : '''DROP TRIGGER @1 failed\n''', 
+    336397274 : '''RECREATE TRIGGER @1 failed\n''', 
+    336397275 : '''CREATE COLLATION @1 failed\n''', 
+    336397276 : '''DROP COLLATION @1 failed\n''', 
+    336397277 : '''CREATE DOMAIN @1 failed\n''', 
+    336397278 : '''ALTER DOMAIN @1 failed\n''', 
+    336397279 : '''DROP DOMAIN @1 failed\n''', 
+    336397280 : '''CREATE EXCEPTION @1 failed\n''', 
+    336397281 : '''ALTER EXCEPTION @1 failed\n''', 
+    336397282 : '''CREATE OR ALTER EXCEPTION @1 failed\n''', 
+    336397283 : '''RECREATE EXCEPTION @1 failed\n''', 
+    336397284 : '''DROP EXCEPTION @1 failed\n''', 
+    336397285 : '''CREATE SEQUENCE @1 failed\n''', 
+    336397286 : '''CREATE TABLE @1 failed\n''', 
+    336397287 : '''ALTER TABLE @1 failed\n''', 
+    336397288 : '''DROP TABLE @1 failed\n''', 
+    336397289 : '''RECREATE TABLE @1 failed\n''', 
+    336397290 : '''CREATE PACKAGE @1 failed\n''', 
+    336397291 : '''ALTER PACKAGE @1 failed\n''', 
+    336397292 : '''CREATE OR ALTER PACKAGE @1 failed\n''', 
+    336397293 : '''DROP PACKAGE @1 failed\n''', 
+    336397294 : '''RECREATE PACKAGE @1 failed\n''', 
+    336397295 : '''CREATE PACKAGE BODY @1 failed\n''', 
+    336397296 : '''DROP PACKAGE BODY @1 failed\n''', 
+    336397297 : '''RECREATE PACKAGE BODY @1 failed\n''', 
+    336397298 : '''CREATE VIEW @1 failed\n''', 
+    336397299 : '''ALTER VIEW @1 failed\n''', 
+    336397300 : '''CREATE OR ALTER VIEW @1 failed\n''', 
+    336397301 : '''RECREATE VIEW @1 failed\n''', 
+    336397302 : '''DROP VIEW @1 failed\n''', 
+    336397303 : '''DROP SEQUENCE @1 failed\n''', 
+    336397304 : '''RECREATE SEQUENCE @1 failed\n''', 
+    336397305 : '''DROP INDEX @1 failed\n''', 
+    336397306 : '''DROP FILTER @1 failed\n''', 
+    336397307 : '''DROP SHADOW @1 failed\n''', 
+    336397308 : '''DROP ROLE @1 failed\n''', 
+    336397309 : '''DROP USER @1 failed\n''', 
+    336397310 : '''CREATE ROLE @1 failed\n''', 
+    336397311 : '''ALTER ROLE @1 failed\n''', 
+    336397312 : '''ALTER INDEX @1 failed\n''', 
+    336397313 : '''ALTER DATABASE failed\n''', 
+    336397314 : '''CREATE SHADOW @1 failed\n''', 
+    336397315 : '''DECLARE FILTER @1 failed\n''', 
+    336397316 : '''CREATE INDEX @1 failed\n''', 
+    336397317 : '''CREATE USER @1 failed\n''', 
+    336397318 : '''ALTER USER @1 failed\n''', 
+    336397319 : '''GRANT failed\n''', 
+    336397320 : '''REVOKE failed\n''', 
+    336397321 : '''Recursive member of CTE cannot use aggregate or window function\n''', 
     336723983 : '''unable to open database\n''', 
     336723984 : '''error in switch specifications\n''', 
     336723985 : '''no operation specified\n''', 
@@ -935,26 +1138,6 @@ messages = {
     336724047 : '''database administrator name already specified\n''', 
     336724048 : '''database administrator password already specified\n''', 
     336724049 : '''SQL role name already specified\n''', 
-    336789504 : '''The license file does not exist or could not be opened for read\n''', 
-    336789523 : '''operation already specified\n''', 
-    336789524 : '''no operation specified\n''', 
-    336789525 : '''invalid switch\n''', 
-    336789526 : '''invalid switch combination\n''', 
-    336789527 : '''illegal operation/switch combination\n''', 
-    336789528 : '''ambiguous switch\n''', 
-    336789529 : '''invalid parameter, no switch specified\n''', 
-    336789530 : '''switch does not take any parameter\n''', 
-    336789531 : '''switch requires a parameter\n''', 
-    336789532 : '''syntax error in command line\n''', 
-    336789534 : '''The certificate was not added.  A duplicate ID exists in the license file.\n''', 
-    336789535 : '''The certificate was not added.  Invalid certificate ID / Key combination.\n''', 
-    336789536 : '''The certificate was not removed.  The key does not exist or corresponds to a temporary evaluation license.\n''', 
-    336789537 : '''An error occurred updating the license file.  Operation cancelled.\n''', 
-    336789538 : '''The certificate could not be validated based on the information given.  Please recheck the ID and key information.\n''', 
-    336789539 : '''Operation failed.  An unknown error occurred.\n''', 
-    336789540 : '''Add license operation failed, KEY: @1 ID: @2\n''', 
-    336789541 : '''Remove license operation failed, KEY: @1\n''', 
-    336789563 : '''The evaluation license has already been used on this server.  You need to purchase a non-evaluation license.\n''', 
     336920577 : '''found unknown switch\n''', 
     336920578 : '''please retry, giving a database name\n''', 
     336920579 : '''Wrong ODS version, expected @1, encountered @2\n''', 
@@ -973,5 +1156,55 @@ messages = {
     336986161 : '''could not read file @1\n''', 
     336986162 : '''empty file @1\n''', 
     336986164 : '''Invalid or missing parameter for switch @1\n''', 
-    337051649 : '''Switches trusted_svc and trusted_role are not supported from command line\n''', 
+    337051649 : '''Switches trusted_user and trusted_role are not supported from command line\n''', 
+    337117213 : '''Missing parameter for switch @1\n''', 
+    337117214 : '''Only one of -LOCK, -UNLOCK, -FIXUP, -BACKUP or -RESTORE should be specified\n''', 
+    337117215 : '''Unrecognized parameter @1\n''', 
+    337117216 : '''Unknown switch @1\n''', 
+    337117217 : '''Fetch password can't be used in service mode\n''', 
+    337117218 : '''Error working with password file "@1"\n''', 
+    337117219 : '''Switch -SIZE can be used only with -LOCK\n''', 
+    337117220 : '''None of -LOCK, -UNLOCK, -FIXUP, -BACKUP or -RESTORE specified\n''', 
+    337117223 : '''IO error reading file: @1\n''', 
+    337117224 : '''IO error writing file: @1\n''', 
+    337117225 : '''IO error seeking file: @1\n''', 
+    337117226 : '''Error opening database file: @1\n''', 
+    337117227 : '''Error in posix_fadvise(@1) for database @2\n''', 
+    337117228 : '''Error creating database file: @1\n''', 
+    337117229 : '''Error opening backup file: @1\n''', 
+    337117230 : '''Error creating backup file: @1\n''', 
+    337117231 : '''Unexpected end of database file @1\n''', 
+    337117232 : '''Database @1 is not in state (@2) to be safely fixed up\n''', 
+    337117233 : '''Database error\n''', 
+    337117234 : '''Username or password is too long\n''', 
+    337117235 : '''Cannot find record for database "@1" backup level @2 in the backup history\n''', 
+    337117236 : '''Internal error. History query returned null SCN or GUID\n''', 
+    337117237 : '''Unexpected end of file when reading header of database file "@1" (stage @2)\n''', 
+    337117238 : '''Internal error. Database file is not locked. Flags are @1\n''', 
+    337117239 : '''Internal error. Cannot get backup guid clumplet\n''', 
+    337117240 : '''Internal error. Database page @1 had been changed during backup (page SCN=@2, backup SCN=@3)\n''', 
+    337117241 : '''Database file size is not a multiple of page size\n''', 
+    337117242 : '''Level 0 backup is not restored\n''', 
+    337117243 : '''Unexpected end of file when reading header of backup file: @1\n''', 
+    337117244 : '''Invalid incremental backup file: @1\n''', 
+    337117245 : '''Unsupported version @1 of incremental backup file: @2\n''', 
+    337117246 : '''Invalid level @1 of incremental backup file: @2, expected @3\n''', 
+    337117247 : '''Wrong order of backup files or invalid incremental backup file detected, file: @1\n''', 
+    337117248 : '''Unexpected end of backup file: @1\n''', 
+    337117249 : '''Error creating database file: @1 via copying from: @2\n''', 
+    337117250 : '''Unexpected end of file when reading header of restored database file (stage @1)\n''', 
+    337117251 : '''Cannot get backup guid clumplet from L0 backup\n''', 
+    337117255 : '''Wrong parameter @1 for switch -D, need ON or OFF\n''', 
+    337117257 : '''Terminated due to user request\n''', 
+    337182750 : '''conflicting actions "@1" and "@2" found\n''', 
+    337182751 : '''action switch not found\n''', 
+    337182752 : '''switch "@1" must be set only once\n''', 
+    337182753 : '''value for switch "@1" is missing\n''', 
+    337182754 : '''invalid value ("@1") for switch "@2"\n''', 
+    337182755 : '''unknown switch "@1" encountered\n''', 
+    337182756 : '''switch "@1" can be used by service only\n''', 
+    337182757 : '''switch "@1" can be used by interactive user only\n''', 
+    337182758 : '''mandatory parameter "@1" for switch "@2" is missing\n''', 
+    337182759 : '''parameter "@1" is incompatible with action "@2"\n''', 
+    337182760 : '''mandatory switch "@1" is missing\n''', 
 }
