@@ -61,9 +61,8 @@ def wire_operation(fn):
     if not DEBUG:
         return fn
     def f(*args, **kwargs):
-        print('<----', fn, args)
+        print('<--', fn, '-->')
         r = fn(*args, **kwargs)
-        print(fn, '---->')
         return r
     return f
 
@@ -145,7 +144,7 @@ class WireProtocol(object):
             r += b
             n -= len(b)
         if len(r) < nbytes:
-            raise OperationalError('Can not recv() packets', None, None)
+            raise OperationalError('Can not recv() packets')
         return r[:nbytes]
 
     def str_to_bytes(self, s):
@@ -306,7 +305,7 @@ class WireProtocol(object):
         blr += bytes([255, 76])    # [blr_end, blr_eoc]
         return blr, values
 
-    def uid(self, use_srp, wire_crypt):
+    def uid(self, auth_plugin_list, wire_crypt):
         def pack_cnct_param(k, v):
             if k != CNCT_specific_data:
                 return bytes([k] + [len(v)]) + v
@@ -327,26 +326,34 @@ class WireProtocol(object):
             user = os.environ.get('USER', '')
             hostname = socket.gethostname()
         r = b''
-        if self.connect_version == 3:
-            if use_srp:
+
+        if auth_plugin_list:
+            if auth_plugin_list[0] == 'Srp':
                 self.client_public_key, self.client_private_key = \
                     srp.client_seed(self.str_to_bytes(self.user.upper()),
                                     self.str_to_bytes(self.password))
-                self.plugin_name = b'Srp'
-                self.plugin_list = b'Srp, Legacy_Auth'
-                specific_data = bytes_to_hex(srp.long2bytes(self.client_public_key))
-            else:
-                self.plugin_name = b'Legacy_Auth'
-                self.plugin_list = b'Legacy_Auth'
+                specific_data = bytes_to_hex(
+                                    srp.long2bytes(self.client_public_key))
+            elif auth_plugin_list[0] == 'Legacy_Auth':
                 specific_data = self.str_to_bytes(
                                         crypt.crypt(self.password, '9z')[2:])
-    
+            else:
+                if not isinstance(auth_plugin_list, tuple):
+                    raise OperationalError("Auth plugin list need tuple.")
+                else:
+                    raise OperationalError(
+                        "Unknown auth plugin name '%s'" % (auth_plugin_list[0]))
+            auth_plugin_list = [s.encode('utf-8') for s in auth_plugin_list]
+            self.plugin_name = auth_plugin_list[0]
+            self.plugin_list = b','.join(auth_plugin_list)
             if wire_crypt:
                 client_crypt = int_to_bytes(1, 4)
             else:
                 client_crypt = int_to_bytes(0, 4)
-    
-            r += pack_cnct_param(CNCT_login, self.str_to_bytes(self.user.upper()))
+
+        if auth_plugin_list:
+            r += pack_cnct_param(CNCT_login,
+                                self.str_to_bytes(self.user.upper()))
             r += pack_cnct_param(CNCT_plugin_name, self.plugin_name)
             r += pack_cnct_param(CNCT_plugin_list, self.plugin_list)
             r += pack_cnct_param(CNCT_specific_data, specific_data)
@@ -357,25 +364,24 @@ class WireProtocol(object):
         return r
 
     @wire_operation
-    def _op_connect(self, use_srp, wire_crypt):
+    def _op_connect(self, auth_plugin_list, wire_crypt):
         arch_type = 36
         min_arch_type = 0
         max_arch_type = 5
         protocol_version_understood_count = 4
-        more_protocol = hex_to_bytes('ffff800b00000001000000000000000500000004ffff800c00000001000000000000000500000006ffff800d00000001000000000000000500000008')
-        if self.connect_version ==2:
-            max_arch_type = 3
-            protocol_version_understood_count = 1
-            more_protocol = b''
+        # accept_type = 5
+#        more_protocol = hex_to_bytes('ffff800b00000001000000000000000500000004ffff800c00000001000000000000000500000006ffff800d00000001000000000000000500000008')
+        # accept_type = 4
+        more_protocol = hex_to_bytes('ffff800b00000001000000000000000400000004ffff800c00000001000000000000000400000006ffff800d00000001000000000000000400000008')
         p = xdrlib.Packer()
         p.pack_int(self.op_connect)
         p.pack_int(self.op_attach)
-        p.pack_int(self.connect_version)
+        p.pack_int(3)   # CONNECT_VERSION
         p.pack_int(arch_type)
         p.pack_string(self.str_to_bytes(self.filename if self.filename else ''))
         p.pack_int(protocol_version_understood_count)
-        p.pack_bytes(self.uid(use_srp, wire_crypt))
-        p.pack_int(10)  # PROTOCOL_VERSION10
+        p.pack_bytes(self.uid(auth_plugin_list, wire_crypt))
+        p.pack_int(PROTOCOL_VERSION10)
         p.pack_int(1)   # Protocol Arch type (Generic = 1)
         p.pack_int(min_arch_type)
         p.pack_int(max_arch_type)
@@ -390,9 +396,13 @@ class WireProtocol(object):
         dpb += bytes([isc_dpb_lc_ctype, len(s)]) + s
         s = self.str_to_bytes(self.user)
         dpb += bytes([isc_dpb_user_name, len(s)]) + s
-        if self.connect_version == 2:
-            s = self.str_to_bytes(self.password)
-            dpb += bytes([isc_dpb_password, len(s)]) + s
+        if self.accept_version < PROTOCOL_VERSION13:
+            if self.accept_version == PROTOCOL_VERSION10:
+                s = self.str_to_bytes(self.password)
+                dpb += bytes([isc_dpb_password, len(s)]) + s
+            else:
+                s = self.str_to_bytes(crypt.crypt(self.password, '9z')[2:])
+                dpb += bytes([isc_dpb_password_enc, len(s)]) + s
         if self.role:
             s = self.str_to_bytes(self.role)
             dpb += bytes([isc_dpb_sql_role_name, len(s)]) + s
@@ -413,14 +423,18 @@ class WireProtocol(object):
         while bytes_to_bint(b) == self.op_dummy:
             b = self.recv_channel(4)
         if bytes_to_bint(b) == self.op_reject:
-            raise OperationalError('Connection is rejected', None, None)
+            raise OperationalError('Connection is rejected')
 
         op_code = bytes_to_bint(b)
-        b = self.recv_channel(12)
-        protocol_version = b[:4]
-        protocol_arch = bytes_to_bint(b[4:8])
-        minimum_type =  bytes_to_bint(b[8:])
+        if op_code == self.op_response:
+            return self._parse_op_response()    # error occured
 
+        b = self.recv_channel(12)
+        self.accept_version = byte_to_int(b[3])
+        self.accept_architecture = bytes_to_bint(b[4:8])
+        self.accept_type =  bytes_to_bint(b[8:])
+
+        self.auth_key = None
         if op_code == self.op_cond_accept or op_code == self.op_accept_data:
             read_length = 0
 
@@ -448,7 +462,7 @@ class WireProtocol(object):
                 read_length += 4 - read_length % 4
 
             if self.plugin_name == b'Legacy_Auth' and is_authenticated == 0:
-                raise OperationalError('Unauthorized', 0, 0)
+                raise OperationalError('Unauthorized')
 
             if self.plugin_name == b'Srp':
                 ln = bytes_to_int(data[:2])
@@ -473,18 +487,18 @@ class WireProtocol(object):
                 self.sock.send(p.get_buffer())
                 (h, oid, buf) = self._op_response()
 
-                # op_crypt: plugin[Arc4] key[Symmetric]
-                p = xdrlib.Packer()
-                p.pack_int(self.op_crypt)
-                p.pack_string('Arc4')
-                p.pack_string('Symmetric')
-                self.sock.send(p.get_buffer())
-                self.sock.set_translator(
-                                    Arc4(self.auth_key), Arc4(self.auth_key))
-                (h, oid, buf) = self._op_response()
         else:
             assert op_code == self.op_accept
-            self.connect_version = 2
+
+        if self.auth_key:
+            # op_crypt: plugin[Arc4] key[Symmetric]
+            p = xdrlib.Packer()
+            p.pack_int(self.op_crypt)
+            p.pack_string(b'Arc4')
+            p.pack_string(b'Symmetric')
+            self.sock.send(p.get_buffer())
+            self.sock.set_translator(Arc4(self.auth_key), Arc4(self.auth_key))
+            (h, oid, buf) = self._op_response()
 
     @wire_operation
     def _op_attach(self):
@@ -493,9 +507,13 @@ class WireProtocol(object):
         dpb += bytes([isc_dpb_lc_ctype, len(s)]) + s
         s = self.str_to_bytes(self.user)
         dpb += bytes([isc_dpb_user_name, len(s)]) + s
-        if self.connect_version == 2:
-            s = self.str_to_bytes(self.password)
-            dpb += bytes([isc_dpb_password, len(s)]) + s
+        if self.accept_version < PROTOCOL_VERSION13:
+            if self.accept_version == PROTOCOL_VERSION10:
+                s = self.str_to_bytes(self.password)
+                dpb += bytes([isc_dpb_password, len(s)]) + s
+            else:
+                s = self.str_to_bytes(crypt.crypt(self.password, '9z')[2:])
+                dpb += bytes([isc_dpb_password_enc, len(s)]) + s
         if self.role:
             s = self.str_to_bytes(self.role)
             dpb += bytes([isc_dpb_sql_role_name, len(s)]) + s
@@ -509,8 +527,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_drop_database(self):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_drop_database() Invalid db handle', None, None)
+            raise OperationalError('_op_drop_database() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_drop_database)
         p.pack_int(self.db_handle)
@@ -534,8 +551,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_service_info(self, param, item, buffer_length=512):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_service_info() Invalid db handle', None, None)
+            raise OperationalError('_op_service_info() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_service_info)
         p.pack_int(self.db_handle)
@@ -548,8 +564,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_service_start(self, param):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_service_start() Invalid db handle', None, None)
+            raise OperationalError('_op_service_start() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_service_start)
         p.pack_int(self.db_handle)
@@ -560,8 +575,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_service_detach(self):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_service_detach() Invalid db handle', None, None)
+            raise OperationalError('_op_service_detach() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_service_detach)
         p.pack_int(self.db_handle)
@@ -570,8 +584,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_info_database(self, b):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_info_database() Invalid db handle', None, None)
+            raise OperationalError('_op_info_database() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_info_database)
         p.pack_int(self.db_handle)
@@ -583,8 +596,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_transaction(self, tpb):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_transaction() Invalid db handle', None, None)
+            raise OperationalError('_op_transaction() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_transaction)
         p.pack_int(self.db_handle)
@@ -622,8 +634,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_allocate_statement(self):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_allocate_statement() Invalid db handle', None, None)
+            raise OperationalError('_op_allocate_statement() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_allocate_statement)
         p.pack_int(self.db_handle)
@@ -716,8 +727,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_exec_immediate(self, trans_handle, query):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_exec_immediate() Invalid db handle', None, None)
+            raise OperationalError('_op_exec_immediate() Invalid db handle')
         desc_items = bytes([])
         p = xdrlib.Packer()
         p.pack_int(self.op_exec_immediate)
@@ -774,8 +784,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_detach(self):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_detach() Invalid db handle', None, None)
+            raise OperationalError('_op_detach() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_detach)
         p.pack_int(self.db_handle)
@@ -838,8 +847,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_que_events(self, event_names, ast, args, event_id):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_que_events() Invalid db handle', None, None)
+            raise OperationalError('_op_que_events() Invalid db handle')
         params = bytes([1])
         for name, n in event_names.items():
             params += bytes([len(name)])
@@ -857,8 +865,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_cancel_events(self, event_id):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_cancel_events() Invalid db handle', None, None)
+            raise OperationalError('_op_cancel_events() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_cancel_events)
         p.pack_int(self.db_handle)
@@ -868,8 +875,7 @@ class WireProtocol(object):
     @wire_operation
     def _op_connect_request(self):
         if self.db_handle is None:
-            raise OperationalError(
-                '_op_connect_request() Invalid db handle', None, None)
+            raise OperationalError('_op_connect_request() Invalid db handle')
         p = xdrlib.Packer()
         p.pack_int(self.op_connect_request)
         p.pack_int(1)    # async
